# gestionatr
[![Build Status](https://travis-ci.org/gisce/gestionatr.svg?branch=master)](https://travis-ci.org/gisce/gestionatr)
[![Coverage Status](https://coveralls.io/repos/github/gisce/gestionatr/badge.svg?branch=master)](https://coveralls.io/github/gisce/gestionatr?branch=master)

Libreria para la generación y carga de ficheros de gestion ATR según define
la CNMC para Electricidad
